@@ -10,7 +10,7 @@ To avoid replicating implementation-dependent test and conversion code.
 
 """
 
-from functools import wraps
+from functools import lru_cache, wraps
 
 import dask
 import dask.array as da
@@ -39,7 +39,7 @@ def is_lazy_data(data):
     """
     Return whether the argument is an Iris 'lazy' data array.
 
-    At present, this means simply a Dask array.
+    At present, this means simply a :class:`dask.array.Array`.
     We determine this by checking for a "compute" property.
 
     """
@@ -47,7 +47,14 @@ def is_lazy_data(data):
     return result
 
 
-def _optimum_chunksize(chunks, shape, limit=None, dtype=np.dtype("f4")):
+@lru_cache
+def _optimum_chunksize_internals(
+    chunks,
+    shape,
+    limit=None,
+    dtype=np.dtype("f4"),
+    dask_array_chunksize=dask.config.get("array.chunk-size"),
+):
     """
     Reduce or increase an initial chunk shape to get close to a chosen ideal
     size, while prioritising the splitting of the earlier (outer) dimensions
@@ -60,7 +67,8 @@ def _optimum_chunksize(chunks, shape, limit=None, dtype=np.dtype("f4")):
     * shape (tuple of int):
         The full array shape of the target data.
     * limit (int):
-        The 'ideal' target chunk size, in bytes.  Default from dask.config.
+        The 'ideal' target chunk size, in bytes.  Default from
+        :mod:`dask.config`.
     * dtype (np.dtype):
         Numpy dtype of target data.
 
@@ -70,7 +78,7 @@ def _optimum_chunksize(chunks, shape, limit=None, dtype=np.dtype("f4")):
 
     .. note::
         The purpose of this is very similar to
-        `dask.array.core.normalize_chunks`, when called as
+        :func:`dask.array.core.normalize_chunks`, when called as
         `(chunks='auto', shape, dtype=dtype, previous_chunks=chunks, ...)`.
         Except, the operation here is optimised specifically for a 'c-like'
         dimension order, i.e. outer dimensions first, as for netcdf variables.
@@ -86,7 +94,7 @@ def _optimum_chunksize(chunks, shape, limit=None, dtype=np.dtype("f4")):
     # Set the chunksize limit.
     if limit is None:
         # Fetch the default 'optimal' chunksize from the dask config.
-        limit = dask.config.get("array.chunk-size")
+        limit = dask_array_chunksize
         # Convert to bytes
         limit = dask.utils.parse_bytes(limit)
 
@@ -146,15 +154,34 @@ def _optimum_chunksize(chunks, shape, limit=None, dtype=np.dtype("f4")):
     return tuple(result)
 
 
+@wraps(_optimum_chunksize_internals)
+def _optimum_chunksize(
+    chunks,
+    shape,
+    limit=None,
+    dtype=np.dtype("f4"),
+):
+    # By providing dask_array_chunksize as an argument, we make it so that the
+    # output of _optimum_chunksize_internals depends only on its arguments (and
+    # thus we can use lru_cache)
+    return _optimum_chunksize_internals(
+        tuple(chunks),
+        tuple(shape),
+        limit=limit,
+        dtype=dtype,
+        dask_array_chunksize=dask.config.get("array.chunk-size"),
+    )
+
+
 def as_lazy_data(data, chunks=None, asarray=False):
     """
-    Convert the input array `data` to a dask array.
+    Convert the input array `data` to a :class:`dask.array.Array`.
 
     Args:
 
     * data (array-like):
         An indexable object with 'shape', 'dtype' and 'ndim' properties.
-        This will be converted to a dask array.
+        This will be converted to a :class:`dask.array.Array`.
 
     Kwargs:
 
@@ -166,7 +193,7 @@ def as_lazy_data(data, chunks=None, asarray=False):
         Set to False (default) to pass passed chunks through unchanged.
 
     Returns:
-        The input array converted to a dask array.
+        The input array converted to a :class:`dask.array.Array`.
 
     .. note::
         The result chunk size is a multiple of 'chunks', if given, up to the
@@ -258,15 +285,16 @@ def multidim_lazy_stack(stack):
     """
     Recursively build a multidimensional stacked dask array.
 
-    This is needed because dask.array.stack only accepts a 1-dimensional list.
+    This is needed because :meth:`dask.array.Array.stack` only accepts a
+    1-dimensional list.
 
     Args:
 
     * stack:
-        An ndarray of dask arrays.
+        An ndarray of :class:`dask.array.Array`.
 
     Returns:
-        The input array converted to a lazy dask array.
+        The input array converted to a lazy :class:`dask.array.Array`.
 
     """
     if stack.ndim == 0:
@@ -359,7 +387,7 @@ def map_complete_blocks(src, func, dims, out_sizes):
 
     Args:
 
-    * src (:class:`~iris.cube.Cube`):
+    * src (:class:`~iris.cube.Cube` or array-like):
         Source cube that function is applied to.
     * func:
         Function to apply.
@@ -369,10 +397,15 @@ def map_complete_blocks(src, func, dims, out_sizes):
         Output size of dimensions that cannot be chunked.
 
     """
-    if not src.has_lazy_data():
+    if is_lazy_data(src):
+        data = src
+    elif not hasattr(src, "has_lazy_data"):
+        # Not a lazy array and not a cube.  So treat as ordinary numpy array.
+        return func(src)
+    elif not src.has_lazy_data():
         return func(src.data)
-
-    data = src.lazy_data()
+    else:
+        data = src.lazy_data()
 
     # Ensure dims are not chunked
     in_chunks = list(data.chunks)
