@@ -213,7 +213,7 @@ class RectilinearInterpolator:
         # Trigger any deferred loading of the source cube's data and snapshot
         # its state to ensure that the interpolator is impervious to external
         # changes to the original source cube. The data is loaded to prevent
-        # the snaphot having lazy data, avoiding the potential for the
+        # the snapshot having lazy data, avoiding the potential for the
         # same data to be loaded again and again.
         if src_cube.has_lazy_data():
             src_cube.data
@@ -268,7 +268,7 @@ class RectilinearInterpolator:
         """
         from iris.analysis.cartography import wrap_lons
 
-        for (circular, modulus, index, dim, offset) in self._circulars:
+        for circular, modulus, index, dim, offset in self._circulars:
             if modulus:
                 # Map all the requested values into the range of the source
                 # data (centred over the centre of the source data to allow
