@@ -147,6 +147,12 @@ cube_delta(temperature_cube, 'pressure')
 
     .. note:: Missing data support not yet implemented.
 
+    .. note::
+
+            This function does not maintain laziness when called; it realises data.
+            See more at :doc:`/userguide/real_and_lazy_data`.
+
+
     """
     # handle the case where a user passes a coordinate name
     if isinstance(coord, str):
@@ -251,6 +257,11 @@ def differentiate(cube, coord_to_differentiate):
 
     .. note:: Spherical differentiation does not occur in this routine.
 
+    .. note::
+
+            This function does not maintain laziness when called; it realises data.
+            See more at :doc:`/userguide/real_and_lazy_data`.
+
     """
     # Get the delta cube in the required differential direction.
     # This operation results in a copy of the original cube.
@@ -532,6 +543,12 @@ def curl(i_cube, j_cube, k_cube=None):
 
             where phi is longitude, theta is latitude.
 
+    .. note::
+
+            This function does not maintain laziness when called; it realises data.
+            See more at :doc:`/userguide/real_and_lazy_data`.
+
+
     """
     # Get the vector quantity names.
     # (i.e. ['easterly', 'northerly', 'vertical'])
@@ -577,7 +594,6 @@ def curl(i_cube, j_cube, k_cube=None):
         horiz_cs, (iris.coord_systems.GeogCS, iris.coord_systems.RotatedGeogCS)
     )
     if not spherical_coords:
-
         # TODO Implement some mechanism for conforming to a common grid
         dj_dx = _curl_differentiate(j_cube, x_coord)
         prototype_diff = dj_dx
@@ -741,6 +757,12 @@ def spatial_vectors_with_phenom_name(i_cube, j_cube, k_cube=None):
 #doctest: +SKIP
         (['u', 'v', 'w'], 'wind')
 
+    Notes
+    ------
+            This function maintains laziness when called; it does not realise data.
+            See more at :doc:`/userguide/real_and_lazy_data`.
+
+
     """
     directional_names = (
         ("u", "v", "w"),
