@@ -5,7 +5,7 @@
 # licensing details.
 
 # import iris tests first so that some things can be initialised before importing anything else
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import unittest
 
@@ -13,12 +13,11 @@ import numpy as np
 
 import iris
 import iris.analysis.calculus
-import iris.cube
 import iris.coord_systems
 import iris.coords
-import iris.tests.stock
-
 from iris.coords import DimCoord
+import iris.cube
+import iris.tests.stock
 
 
 class TestCubeDelta(tests.IrisTest):
