@@ -15,6 +15,7 @@ import numpy as np
 import numpy.ma as ma
 
 from iris.analysis import Aggregator
+from iris.cube import Cube
 from iris.exceptions import LazyAggregatorError
 
 
@@ -156,6 +157,19 @@ class Test_aggregate(tests.IrisTest):
             self.assertArrayAlmostEqual(result, mock_return.copy())
         mock_method.assert_called_once_with(data, axis=axis)
 
+    def test_allmasked_1D_with_mdtol(self):
+        data = ma.masked_all((3,))
+        axis = 0
+        mdtol = 0.5
+        mock_return = ma.masked
+        with mock.patch.object(
+            self.TEST, "call_func", return_value=mock_return
+        ) as mock_method:
+            result = self.TEST.aggregate(data, axis, mdtol=mdtol)
+
+        self.assertIs(result, mock_return)
+        mock_method.assert_called_once_with(data, axis=axis)
+
     def test_returning_scalar_mdtol(self):
         # Test the case when the data aggregation function returns a scalar and
         # turns it into a masked array.
@@ -273,10 +287,30 @@ class Test_update_metadata(tests.IrisTest):
         units_func = mock.Mock(return_value=mock.sentinel.new_units)
         aggregator = Aggregator("", None, units_func)
         cube = mock.Mock(units=mock.sentinel.units)
-        aggregator.update_metadata(cube, [])
-        units_func.assert_called_once_with(mock.sentinel.units)
+        aggregator.update_metadata(cube, [], kw1=1, kw2=2)
+        units_func.assert_called_once_with(mock.sentinel.units, kw1=1, kw2=2)
         self.assertEqual(cube.units, mock.sentinel.new_units)
 
+    def test_units_func_no_kwargs(self):
+        # To ensure backwards-compatibility, Aggregator also supports
+        # units_func that accept the single argument `units`
+        def units_func(units):
+            return units**2
+
+        aggregator = Aggregator("", None, units_func)
+        cube = Cube(0, units="s")
+        aggregator.update_metadata(cube, [], kw1=1, kw2=2)
+        self.assertEqual(cube.units, "s2")
+
+    def test_units_func_kwargs(self):
+        def units_func(units, **kwargs):
+            return units**2
+
+        aggregator = Aggregator("", None, units_func)
+        cube = Cube(0, units="s")
+        aggregator.update_metadata(cube, [], kw1=1, kw2=2)
+        self.assertEqual(cube.units, "s2")
+
 
 class Test_lazy_aggregate(tests.IrisTest):
     def test_kwarg_pass_through_no_kwargs(self):
