@@ -8,16 +8,18 @@ Test function :func:`iris.fileformats._nc_load_rules.helpers.\
 build_auxilliary_coordinate`.
 
 """
-
 # import iris tests first so that some things can be initialised before
 # importing anything else
 import iris.tests as tests  # isort:skip
 
+import contextlib
 from unittest import mock
 
 import numpy as np
+import pytest
 
 from iris.coords import AuxCoord
+from iris.exceptions import CannotAddError
 from iris.fileformats._nc_load_rules.helpers import build_auxiliary_coordinate
 from iris.fileformats.cf import CFVariable
 
@@ -46,6 +48,7 @@ class TestBoundsVertexDim(tests.IrisTest):
             long_name="wibble",
             units="m",
             shape=points.shape,
+            size=np.prod(points.shape),
             dtype=points.dtype,
             __getitem__=lambda self, key: points[key],
         )
@@ -109,6 +112,7 @@ class TestBoundsVertexDim(tests.IrisTest):
             cf_name="wibble_bnds",
             cf_data=cf_data,
             shape=bounds.shape,
+            size=np.prod(bounds.shape),
             dtype=bounds.dtype,
             __getitem__=lambda self, key: bounds[key],
         )
@@ -163,6 +167,7 @@ class TestDtype(tests.IrisTest):
             long_name="wibble",
             units="m",
             shape=points.shape,
+            size=np.prod(points.shape),
             dtype=points.dtype,
             __getitem__=lambda self, key: points[key],
         )
@@ -174,21 +179,29 @@ class TestDtype(tests.IrisTest):
             cube_parts=dict(coordinates=[]),
         )
 
+    @contextlib.contextmanager
+    def deferred_load_patch(self):
         def patched__getitem__(proxy_self, keys):
             if proxy_self.variable_name == self.cf_coord_var.cf_name:
                 return self.cf_coord_var[keys]
             raise RuntimeError()
 
-        self.deferred_load_patch = mock.patch(
+        # Fix for deferred load, *AND* avoid loading small variable data in real arrays.
+        with mock.patch(
             "iris.fileformats.netcdf.NetCDFDataProxy.__getitem__",
             new=patched__getitem__,
-        )
+        ):
+            # While loading, "turn off" loading small variables as real data.
+            with mock.patch(
+                "iris.fileformats.netcdf.loader._LAZYVAR_MIN_BYTES", 0
+            ):
+                yield
 
     def test_scale_factor_add_offset_int(self):
         self.cf_coord_var.scale_factor = 3
         self.cf_coord_var.add_offset = 5
 
-        with self.deferred_load_patch:
+        with self.deferred_load_patch():
             build_auxiliary_coordinate(self.engine, self.cf_coord_var)
 
         coord, _ = self.engine.cube_parts["coordinates"][0]
@@ -197,7 +210,7 @@ class TestDtype(tests.IrisTest):
     def test_scale_factor_float(self):
         self.cf_coord_var.scale_factor = 3.0
 
-        with self.deferred_load_patch:
+        with self.deferred_load_patch():
             build_auxiliary_coordinate(self.engine, self.cf_coord_var)
 
         coord, _ = self.engine.cube_parts["coordinates"][0]
@@ -206,7 +219,7 @@ class TestDtype(tests.IrisTest):
     def test_add_offset_float(self):
         self.cf_coord_var.add_offset = 5.0
 
-        with self.deferred_load_patch:
+        with self.deferred_load_patch():
             build_auxiliary_coordinate(self.engine, self.cf_coord_var)
 
         coord, _ = self.engine.cube_parts["coordinates"][0]
@@ -237,6 +250,7 @@ class TestCoordConstruction(tests.IrisTest):
             units="days since 1970-01-01",
             calendar=None,
             shape=points.shape,
+            size=np.prod(points.shape),
             dtype=points.dtype,
             __getitem__=lambda self, key: points[key],
         )
@@ -249,6 +263,7 @@ class TestCoordConstruction(tests.IrisTest):
             cf_name="wibble_bnds",
             cf_data=mock.MagicMock(chunking=mock.Mock(return_value=None)),
             shape=bounds.shape,
+            size=np.prod(bounds.shape),
             dtype=bounds.dtype,
             __getitem__=lambda self, key: bounds[key],
         )
@@ -280,6 +295,11 @@ class TestCoordConstruction(tests.IrisTest):
             new=get_cf_bounds_var,
         )
 
+        # test_not_added() has been written in pytest-style, but the rest of
+        #  the class is pending migration. Defining self.monkeypatch (not the
+        #  typical practice in pure pytest) allows this transitional state.
+        self.monkeypatch = pytest.MonkeyPatch()
+
     def check_case_aux_coord_construction(self, climatology=False):
         # Test a generic auxiliary coordinate, with or without
         # a climatological coord.
@@ -305,6 +325,19 @@ class TestCoordConstruction(tests.IrisTest):
     def test_aux_coord_construction__climatology(self):
         self.check_case_aux_coord_construction(climatology=True)
 
+    def test_not_added(self):
+        # Confirm that the coord will be skipped if a CannotAddError is raised
+        #  when attempting to add.
+        def mock_add_aux_coord(_, __):
+            raise CannotAddError("foo")
+
+        with self.monkeypatch.context() as m:
+            m.setattr(self.engine.cube, "add_aux_coord", mock_add_aux_coord)
+            with pytest.warns(match="coordinate not added to Cube: foo"):
+                build_auxiliary_coordinate(self.engine, self.cf_coord_var)
+
+        assert self.engine.cube_parts["coordinates"] == []
+
 
 if __name__ == "__main__":
     tests.main()
