@@ -349,6 +349,20 @@ class TestCubePrintout__to_string(tests.IrisTest):
         ]
         self.assertEqual(rep, expected)
 
+    def test_section_vector_ancils_length_1(self):
+        # Check ancillary variables that map to a cube dimension of length 1
+        # are not interpreted as scalar ancillary variables.
+        cube = Cube(np.zeros((1, 3)), long_name="name", units=1)
+        cube.add_ancillary_variable(AncillaryVariable([0], long_name="av1"), 0)
+
+        rep = cube_replines(cube)
+        expected = [
+            "name / (1)                          (-- : 1; -- : 3)",
+            "    Ancillary variables:",
+            "        av1                             x       -",
+        ]
+        self.assertEqual(rep, expected)
+
     def test_section_vector_cell_measures(self):
         cube = Cube(np.zeros((2, 3)), long_name="name", units=1)
         cube.add_cell_measure(CellMeasure([0, 1, 2], long_name="cm"), 1)
@@ -361,6 +375,20 @@ class TestCubePrintout__to_string(tests.IrisTest):
         ]
         self.assertEqual(rep, expected)
 
+    def test_section_vector_cell_measures_length_1(self):
+        # Check cell measures that map to a cube dimension of length 1 are not
+        # interpreted as scalar cell measures.
+        cube = Cube(np.zeros((2, 1)), long_name="name", units=1)
+        cube.add_cell_measure(CellMeasure([0], long_name="cm"), 1)
+
+        rep = cube_replines(cube)
+        expected = [
+            "name / (1)                          (-- : 2; -- : 1)",
+            "    Cell measures:",
+            "        cm                              -       x",
+        ]
+        self.assertEqual(rep, expected)
+
     def test_section_scalar_coords(self):
         # incl points + bounds
         # TODO: ought to incorporate coord-based summary
@@ -424,8 +452,8 @@ class TestCubePrintout__to_string(tests.IrisTest):
         rep = cube_replines(cube)
         expected = [
             "name / (1)                          (-- : 2; -- : 3)",
-            "    Ancillary variables:",
-            "        av                              -       -",
+            "    Scalar ancillary variables:",
+            "        av",
         ]
         self.assertEqual(rep, expected)
 
@@ -465,11 +493,11 @@ class TestCubePrintout__to_string(tests.IrisTest):
             "        escaped                     'escaped\\tstring'",
             (
                 "        long                        'this is very very very "
-                "very very very very very very very very very very..."
+                "very very very very very very very very very very ...'"
             ),
             (
                 "        long_multi                  'multi\\nline, "
-                "this is very very very very very very very very very very..."
+                "this is very very very very very very very very very very ...'"
             ),
         ]
         self.assertEqual(rep, expected)
@@ -488,7 +516,7 @@ class TestCubePrintout__to_string(tests.IrisTest):
             "        array                       array([1.2, 3.4])",
             (
                 "        bigarray                    array([[ 0, 1], [ 2, 3], "
-                "[ 4, 5], [ 6, 7], [ 8, 9], [10, 11], [12, 13],..."
+                "[ 4, 5], [ 6, 7], [ 8, 9], [10, 11], [12, 13], ..."
             ),
         ]
         self.assertEqual(rep, expected)
@@ -509,10 +537,11 @@ class TestCubePrintout__to_string(tests.IrisTest):
         expected = [
             "name / (1)                          (-- : 1)",
             "    Cell methods:",
-            "        stdev                       area",
-            "        mean                        y (10m, vertical), time (3min, =duration)",
+            "        0                           area: stdev",
+            "        1                           y: time: mean (interval: 10m"
+            " interval: 3min comment: vertical comment: =duration)",
         ]
-        self.assertEqual(rep, expected)
+        self.assertEqual(expected, rep)
 
     def test_unstructured_cube(self):
         # Check a sample mesh-cube against the expected result.
@@ -528,6 +557,9 @@ class TestCubePrintout__to_string(tests.IrisTest):
             "        longitude                         -               x",
             "    Auxiliary coordinates:",
             "        mesh_face_aux                     -               x",
+            "    Mesh:",
+            "        name                        unknown",
+            "        location                    face",
         ]
         self.assertEqual(rep, expected)
 
